# eui
a fast and simple micro-framework for small browser-based applications

## example
### Step 1:
create python file, `main.py`:
```python
import eui
import webbrowser
import os


def say_hello(message):
    print('receive message from js:', message)
    eui.js('sayHello', message)


def startup_callback():
    # open UI file in browser
    webbrowser.open(os.getcwd() + '/static/index.html')


handlers = {
    'say_hello': say_hello
}

eui.start(handlers=handlers, startup_callback=startup_callback)

```

### Step 2:
create UI file `index.html` in `static` folder:
```html
<!DOCTYPE HTML>
<html>

<head>
   <meta charset="utf-8">
   <title>eui test</title>
   <script src="eui.js"></script>
   <script type="text/javascript">
      function sendMessage() {
         var message = document.getElementById('message').value;
         eui.py('say_hello', message);
      }

      function sayHello(message) {
         alert('receive message from py: ' + message);
      }

   </script>

</head>

<body>
   <input id="message">
   <button onclick="sendMessage()">Send</button>

</body>

</html>

```

### Step 3:
run `main.py`
snapshot:
![snapshot](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAABRkAAAKsCAYAAABoJrrOAAAAAXNSR0IArs4c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%0ATkSuQmCC)
